@@ -4,7 +4,7 @@
  * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2014-2018 Kalev Lember <klember@redhat.com>
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -70,7 +70,8 @@ packagekit_status_enum_to_plugin_status (PkStatusEnum status)
 }
 
 gboolean
-gs_plugin_packagekit_error_convert (GError **error)
+gs_plugin_packagekit_error_convert (GError **error,
+				    GCancellable *check_cancellable)
 {
 	GError *error_tmp;
 
@@ -97,6 +98,12 @@ gs_plugin_packagekit_error_convert (GError **error)
 	if (error_tmp->domain != PK_CLIENT_ERROR)
 		return FALSE;
 
+	if (g_cancellable_is_cancelled (check_cancellable)) {
+		error_tmp->domain = GS_PLUGIN_ERROR;
+		error_tmp->code = GS_PLUGIN_ERROR_CANCELLED;
+		return TRUE;
+	}
+
 	/* daemon errors */
 	if (error_tmp->code <= 0xff) {
 		switch (error_tmp->code) {
@@ -173,13 +180,15 @@ gs_plugin_packagekit_error_convert (GError **error)
 }
 
 gboolean
-gs_plugin_packagekit_results_valid (PkResults *results, GError **error)
+gs_plugin_packagekit_results_valid (PkResults *results,
+				    GCancellable *check_cancellable,
+				    GError **error)
 {
 	g_autoptr(PkError) error_code = NULL;
 
 	/* method failed? */
 	if (results == NULL) {
-		gs_plugin_packagekit_error_convert (error);
+		gs_plugin_packagekit_error_convert (error, check_cancellable);
 		return FALSE;
 	}
 
@@ -190,7 +199,7 @@ gs_plugin_packagekit_results_valid (PkResults *results, GError **error)
 				     PK_CLIENT_ERROR,
 				     pk_error_get_code (error_code),
 				     pk_error_get_details (error_code));
-		gs_plugin_packagekit_error_convert (error);
+		gs_plugin_packagekit_error_convert (error, check_cancellable);
 		return FALSE;
 	}
 
@@ -506,9 +515,8 @@ gs_plugin_packagekit_refine_details_app (GsPlugin *plugin,
 	 * repository, on the order of 400 or 700 apps */
 	source_ids = gs_app_get_source_ids (app);
 	for (j = 0; j < source_ids->len; j++) {
-		#ifdef HAVE_PK_DETAILS_GET_DOWNLOAD_SIZE
 		guint64 download_sz;
-		#endif
+
 		package_id = g_ptr_array_index (source_ids, j);
 		details = g_hash_table_lookup (details_collection, package_id);
 		if (details == NULL)
@@ -534,7 +542,6 @@ gs_plugin_packagekit_refine_details_app (GsPlugin *plugin,
 			                        pk_details_get_description (details));
 		}
 		install_size += pk_details_get_size (details);
-		#ifdef HAVE_PK_DETAILS_GET_DOWNLOAD_SIZE
 		download_sz = pk_details_get_download_size (details);
 
 		/* If the package is already prepared as part of an offline
@@ -542,13 +549,8 @@ gs_plugin_packagekit_refine_details_app (GsPlugin *plugin,
 		if (download_sz != G_MAXUINT64 &&
 		    !g_hash_table_contains (prepared_updates, package_id))
 			download_size += download_sz;
-		#endif
 	}
 
-	#ifndef HAVE_PK_DETAILS_GET_DOWNLOAD_SIZE
-	download_size = install_size;
-	#endif
-
 	/* the size is the size of all sources */
 	if (gs_app_get_state (app) == GS_APP_STATE_UPDATABLE) {
 		if (install_size > 0 && gs_app_get_size_installed (app, NULL) != GS_SIZE_TYPE_VALID)
