@@ -5,7 +5,7 @@
  * Copyright (C) 2013 Matthias Clasen <mclasen@redhat.com>
  * Copyright (C) 2015 Kalev Lember <klember@redhat.com>
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -26,7 +26,7 @@ main (int argc, char **argv)
 	int status = 0;
 	g_autoptr(GDesktopAppInfo) appinfo = NULL;
 	g_autoptr(GsApplication) application = NULL;
-	g_autoptr(GsDebug) debug = gs_debug_new ();
+	g_autoptr(GsDebug) debug = gs_debug_new_from_environment ();
 
 	g_set_prgname ("org.gnome.Software");
 	setlocale (LC_ALL, "");
@@ -43,9 +43,10 @@ main (int argc, char **argv)
 	umask (022);
 
 	/* redirect logs */
-	application = gs_application_new ();
+	application = gs_application_new (debug);
 	appinfo = g_desktop_app_info_new ("org.gnome.Software.desktop");
-	g_set_application_name (g_app_info_get_name (G_APP_INFO (appinfo)));
+	if (appinfo != NULL)
+		g_set_application_name (g_app_info_get_name (G_APP_INFO (appinfo)));
 	status = g_application_run (G_APPLICATION (application), argc, argv);
 	return status;
 }
