@@ -5,7 +5,7 @@
  *
  * Author: Philip Withnall <pwithnall@endlessos.org>
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /**
@@ -112,7 +112,6 @@ update_permissions_list (GsSafetyContextDialog *self)
 	g_autoptr(GPtrArray) descriptions = g_ptr_array_new_with_free_func (NULL);
 	g_autoptr(GsAppPermissions) permissions = NULL;
 	GsAppPermissionsFlags perm_flags = GS_APP_PERMISSIONS_FLAGS_UNKNOWN;
-	GtkStyleContext *context;
 	GsContextDialogRowImportance chosen_rating;
 
 	/* Treat everything as safe to begin with, and downgrade its safety
@@ -129,7 +128,7 @@ update_permissions_list (GsSafetyContextDialog *self)
 	if (permissions != NULL)
 		perm_flags = gs_app_permissions_get_flags (permissions);
 
-	/* Handle unknown permissions. This means the application isn’t
+	/* Handle unknown permissions. This means the app isn’t
 	 * sandboxed, so we can only really base decisions on whether it was
 	 * packaged by an organisation we trust or not.
 	 *
@@ -141,10 +140,10 @@ update_permissions_list (GsSafetyContextDialog *self)
 				    GS_CONTEXT_DIALOG_ROW_IMPORTANCE_WARNING,
 				    "channel-insecure-symbolic",
 				    _("Provided by a third party"),
-				    _("Check that you trust the vendor, as the application isn’t sandboxed"),
+				    _("Check that you trust the vendor, as the app isn’t sandboxed"),
 				    "channel-secure-symbolic",
 				    _("Reviewed by your distribution"),
-				    _("Application isn’t sandboxed but the distribution has checked that it is not malicious"));
+				    _("App isn’t sandboxed but the distribution has checked that it is not malicious"));
 	} else {
 		const GPtrArray *filesystem_read, *filesystem_full;
 
@@ -196,12 +195,20 @@ update_permissions_list (GsSafetyContextDialog *self)
 				    GS_CONTEXT_DIALOG_ROW_IMPORTANCE_WARNING,
 				    "camera-photo-symbolic",
 				    /* Translators: This refers to permissions (for example, from flatpak) which an app requests from the user. */
-				    _("Device Access"),
+				    _("User Device Access"),
 				    _("Can access devices such as webcams or gaming controllers"),
 				    "camera-disabled-symbolic",
 				    /* Translators: This refers to permissions (for example, from flatpak) which an app requests from the user. */
-				    _("No Device Access"),
+				    _("No User Device Access"),
 				    _("Cannot access devices such as webcams or gaming controllers"));
+		add_permission_row (self->permissions_list, &chosen_rating,
+				    (perm_flags & GS_APP_PERMISSIONS_FLAGS_SYSTEM_DEVICES) != 0,
+				    GS_CONTEXT_DIALOG_ROW_IMPORTANCE_WARNING,
+				    "computer-chip-symbolic",
+				    /* Translators: This refers to permissions (for example, from flatpak) which an app requests from the user. */
+				    _("System Device Access"),
+				    _("Can access system devices which require elevated permissions"),
+				    NULL, NULL, NULL);
 		add_permission_row (self->permissions_list, &chosen_rating,
 				    (perm_flags & GS_APP_PERMISSIONS_FLAGS_X11) != 0,
 				    GS_CONTEXT_DIALOG_ROW_IMPORTANCE_IMPORTANT,
@@ -397,13 +404,11 @@ update_permissions_list (GsSafetyContextDialog *self)
 	gs_lozenge_set_icon_name (GS_LOZENGE (self->lozenge), icon_name);
 	gtk_label_set_text (self->title, title);
 
-	context = gtk_widget_get_style_context (self->lozenge);
+	gtk_widget_remove_css_class (self->lozenge, "green");
+	gtk_widget_remove_css_class (self->lozenge, "yellow");
+	gtk_widget_remove_css_class (self->lozenge, "red");
 
-	gtk_style_context_remove_class (context, "green");
-	gtk_style_context_remove_class (context, "yellow");
-	gtk_style_context_remove_class (context, "red");
-
-	gtk_style_context_add_class (context, css_class);
+	gtk_widget_add_css_class (self->lozenge, css_class);
 }
 
 static void
@@ -428,7 +433,6 @@ update_sdk (GsSafetyContextDialog *self)
 	runtime = gs_app_get_runtime (self->app);
 
 	if (runtime != NULL) {
-		GtkStyleContext *context;
 		g_autofree gchar *label = NULL;
 		const gchar *version = gs_app_get_version_ui (runtime);
 		gboolean is_eol = gs_app_get_metadata_item (runtime, "GnomeSoftware::EolReason") != NULL;
@@ -445,14 +449,12 @@ update_sdk (GsSafetyContextDialog *self)
 
 		gtk_label_set_label (self->sdk_label, label);
 
-		context = gtk_widget_get_style_context (GTK_WIDGET (self->sdk_label));
-
 		if (is_eol) {
-			gtk_style_context_add_class (context, "eol-red");
-			gtk_style_context_remove_class (context, "dim-label");
+			gtk_widget_add_css_class (GTK_WIDGET (self->sdk_label), "eol-red");
+			gtk_widget_remove_css_class (GTK_WIDGET (self->sdk_label), "dim-label");
 		} else {
-			gtk_style_context_add_class (context, "dim-label");
-			gtk_style_context_remove_class (context, "eol-red");
+			gtk_widget_add_css_class (GTK_WIDGET (self->sdk_label), "dim-label");
+			gtk_widget_remove_css_class (GTK_WIDGET (self->sdk_label), "eol-red");
 		}
 
 		gtk_widget_set_visible (GTK_WIDGET (self->sdk_eol_image), is_eol);
